@@ -3,5 +3,5 @@ from pkg_resources import get_distribution, DistributionNotFound
 version = get_distribution(__name__).version
 
 from .offline import OfflineReader
-from .daq import DAQReader
+from .online import OnlineReader
 from .gseagen import GSGReader
